@@ -94,7 +94,7 @@ qgmp_urandomb_ui qgmp_urandomm_ui
     );
 
     @Math::GMPq::EXPORT_OK = (@untagged, @tagged);
-    our $VERSION = '0.63';
+    our $VERSION = '0.64';
     #$VERSION = eval $VERSION;
 
     Math::GMPq->DynaLoader::bootstrap($VERSION);
@@ -178,6 +178,12 @@ sub new {
       return $ret;
     }
 
+    if($type == _MATH_MPFR_T) {
+      if(@_) {die "Too many arguments supplied to new() - expected only one"}
+      Math::MPFR::Rmpfr_get_q($ret, $arg1);
+      return $ret;
+    }
+
     if($type == _MATH_GMPq_T) { # Math::GMPq object
       if(@_) {die "Too many arguments supplied to new() - expected only one"}
       Rmpq_set($ret, $arg1);
